Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Repository ¶
type Repository interface {
Create(destination *form.DestinationForm) (interface{}, error)
Find(search string) (interface{}, error)
FindByID(id string) (interface{}, error)
FindIndex() (bool, error)
Delete(id string) error
}
Repository represent the repositories
func NewElasticsearchRepository ¶
func NewElasticsearchRepository(Client *elastic.Client) Repository
NewElasticsearchRepository will create an object that represent the Repository interface
type Service ¶
type Service interface {
Create(user *form.DestinationForm) (interface{}, int, error)
Find(search string) (interface{}, int, error)
FindByID(id string) (interface{}, int, error)
FindIndex() (bool, int, error)
Delete(id string) (int, error)
}
Service represent the services
func NewService ¶
func NewService(log *logrus.Entry, r Repository) Service
NewService will create an object that represent the Service interface
Click to show internal directories.
Click to hide internal directories.